# Generated by Django 2.2.4 on 2019-08-29 14:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("options", "0003_auto_20190827_0605")]

    operations = [
        migrations.AddField(
            model_name="option",
            name="is_public",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="useroption",
            name="is_public",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="option",
            name="public_name",
            field=models.CharField(
                blank=True,
                db_index=True,
                max_length=255,
                verbose_name="public name of the parameter",
            ),
        ),
        migrations.AlterField(
            model_name="useroption",
            name="name",
            field=models.CharField(max_length=255, verbose_name="parameter name"),
        ),
        migrations.AlterField(
            model_name="useroption",
            name="public_name",
            field=models.CharField(
                blank=True,
                db_index=True,
                max_length=255,
                verbose_name="public name of the parameter",
            ),
        ),
    ]
