# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-02-23 15:53
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Option",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        db_index=True,
                        max_length=255,
                        unique=True,
                        verbose_name="Parameter",
                    ),
                ),
                (
                    "public_name",
                    models.CharField(
                        db_index=True,
                        max_length=255,
                        verbose_name="Public name of the parameter",
                    ),
                ),
                (
                    "type",
                    models.PositiveIntegerField(
                        choices=[(0, "Float"), (1, "Integer"), (2, "String")], default=2
                    ),
                ),
                (
                    "value",
                    models.CharField(
                        blank=True,
                        default=None,
                        max_length=256,
                        null=True,
                        verbose_name="Value",
                    ),
                ),
                ("is_list", models.BooleanField(default=False)),
            ],
        )
    ]
