# Generated by Django 2.2.4 on 2019-08-27 11:05

from django.db import migrations, models
import options.helpers


class Migration(migrations.Migration):

    dependencies = [("options", "0002_auto_20181002_0254")]

    operations = [
        migrations.AddField(
            model_name="option",
            name="file",
            field=models.FileField(
                blank=True,
                null=True,
                upload_to=options.helpers.UploadToDir("options", random_name=True),
            ),
        ),
        migrations.AddField(
            model_name="useroption",
            name="file",
            field=models.FileField(
                blank=True,
                null=True,
                upload_to=options.helpers.UploadToDir("options", random_name=True),
            ),
        ),
        migrations.AlterField(
            model_name="option",
            name="name",
            field=models.CharField(
                db_index=True,
                max_length=255,
                unique=True,
                verbose_name="parameter name",
            ),
        ),
        migrations.AlterField(
            model_name="option",
            name="public_name",
            field=models.CharField(
                db_index=True,
                max_length=255,
                verbose_name="public name of the parameter",
            ),
        ),
        migrations.AlterField(
            model_name="option",
            name="type",
            field=models.PositiveIntegerField(
                choices=[(0, "Float"), (1, "Integer"), (2, "String"), (3, "File")],
                default=2,
            ),
        ),
        migrations.AlterField(
            model_name="option",
            name="value",
            field=models.CharField(
                blank=True,
                default=None,
                max_length=256,
                null=True,
                verbose_name="value",
            ),
        ),
        migrations.AlterField(
            model_name="useroption",
            name="public_name",
            field=models.CharField(
                db_index=True,
                max_length=255,
                verbose_name="public name of the parameter",
            ),
        ),
        migrations.AlterField(
            model_name="useroption",
            name="type",
            field=models.PositiveIntegerField(
                choices=[(0, "Float"), (1, "Integer"), (2, "String"), (3, "File")],
                default=2,
            ),
        ),
        migrations.AlterField(
            model_name="useroption",
            name="value",
            field=models.CharField(
                blank=True,
                default=None,
                max_length=256,
                null=True,
                verbose_name="value",
            ),
        ),
    ]
