#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['options',
 'options.management',
 'options.management.commands',
 'options.migrations']

package_data = \
{'': ['*'], 'options': ['rest_framework/*']}

install_requires = \
['django']

extras_require = \
{'doc': ['sphinx'],
 'test': ['pytest', 'pytest-django', 'pytest-cov', 'factory_boy']}

setup(name='django-simple-options',
      version='2.1.1',
      description='Simple app to add configuration options to a Django project.',
      author='Marcos Gabarda',
      author_email='hey@marcosgabarda.com',
      url='https://github.com/marcosgabarda/django-simple-options',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      python_requires='>=3.6',
     )
